@@ -1,12 +1,12 @@
 import os
-KRnPx=Exception
-KRnPg=False
-KRnPi=str
-KRnPW=int
-KRnPD=range
-KRnPF=len
-KRnPS=object
-KRnPj=True
+ExwvX=Exception
+ExwvK=False
+Exwvy=str
+Exwve=int
+Exwvi=range
+ExwvS=len
+Exwvq=object
+ExwvM=True
 import re
 import sys
 import glob
@@ -15,7 +15,7 @@ import base64
 import logging
 import pyaes
 from localstack import config as localstack_config
-from localstack.utils.common import(safe_requests as requests,load_file,save_file,to_str,to_bytes,md5,parallelize,get_or_create_file,now_utc,str_insert,str_remove)
+from localstack.utils.common import(safe_requests as requests,load_file,save_file,to_str,to_bytes,md5,parallelize,now_utc,str_insert,str_remove)
 from localstack_ext import config
 from localstack_ext.config import PROTECTED_FOLDERS,ROOT_FOLDER
 from localstack_ext.constants import VERSION
@@ -26,7 +26,7 @@ def read_api_key():
  key=os.environ.get('LOCALSTACK_API_KEY')
  if key:
   return key
- raise KRnPx('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
+ raise ExwvX('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
 def fetch_key():
  api_key=read_api_key()
  if api_key=='test':
@@ -34,38 +34,36 @@ def fetch_key():
  data={'api_key':api_key,'version':VERSION}
  try:
   logging.getLogger('py.warnings').setLevel(logging.ERROR)
-  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=KRnPg)
+  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=ExwvK)
   key_base64=json.loads(result.content)['key']
   cache_key_locally(api_key,key_base64)
- except KRnPx:
+ except ExwvX:
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger('py.warnings').setLevel(logging.WARNING)
  decoded_key=to_str(base64.b64decode(key_base64))
  return decoded_key
 def cache_key_locally(api_key,key_b64):
- content=get_or_create_file(localstack_config.CONFIG_FILE_PATH)
- configs=json.loads(to_str(content))
- timestamp=KRnPi(KRnPW(now_utc()))
+ configs=localstack_config.load_config_file()
+ timestamp=Exwvy(Exwve(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in KRnPD(KRnPF(timestamp)):
+ for i in Exwvi(ExwvS(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs['cached_key']={'timestamp':KRnPW(timestamp),'key_hash':md5(api_key),'key':key_b64}
+ configs['cached_key']={'timestamp':Exwve(timestamp),'key_hash':md5(api_key),'key':key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
- content=get_or_create_file(localstack_config.CONFIG_FILE_PATH)
- configs=json.loads(to_str(content))
+ configs=localstack_config.load_config_file()
  cached_key=configs['cached_key']
  if cached_key.get('key_hash')!=md5(api_key):
-  raise KRnPx('Cached key was created for a different API key')
+  raise ExwvX('Cached key was created for a different API key')
  now=now_utc()
  if(now-cached_key['timestamp'])>MAX_KEY_CACHE_DURATION_SECS:
-  raise KRnPx('Cached key expired')
- timestamp=KRnPi(cached_key['timestamp'])
+  raise ExwvX('Cached key expired')
+ timestamp=Exwvy(cached_key['timestamp'])
  key_raw=to_str(base64.b64decode(cached_key['key']))
- for i in KRnPD(KRnPF(timestamp)):
+ for i in Exwvi(ExwvS(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -104,11 +102,11 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(KRnPS):
+ class OnClose(Exwvq):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get('finalized'):
     cleanup_environment()
-   ENV_PREPARED['finalized']=KRnPj
+   ENV_PREPARED['finalized']=ExwvM
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get('finalized'):
@@ -117,10 +115,20 @@ def prepare_environment():
    if key!='test':
     decrypt_files(key)
     LOG.info('Successfully activated API key')
-  except KRnPx:
+  except ExwvX:
    if config.REQUIRE_PRO:
     LOG.error('Unable to activate API key, but $REQUIRE_PRO is configured - quitting.')
     sys.exit(1)
    pass
  return OnClose()
+def get_auth_headers():
+ configs=localstack_config.load_config_file()
+ login_info=configs.get('login')
+ if not login_info:
+  raise ExwvX('Please log in first')
+ auth_token=login_info['token']
+ if not auth_token.startswith('%s '%login_info['provider']):
+  auth_token='%s %s'%(login_info['provider'],auth_token)
+ headers={'authorization':auth_token}
+ return headers
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
