@@ -1,13 +1,16 @@
 import os
-aEDPU=object
-aEDPV=None
-aEDPC=Exception
-aEDPT=set
-aEDPh=property
-aEDPm=classmethod
-aEDPy=False
-aEDPA=True
-aEDPG=getattr
+jGcyT=object
+jGcyH=None
+jGcyA=Exception
+jGcyI=set
+jGcyx=property
+jGcyq=classmethod
+jGcyR=True
+jGcyY=getattr
+jGcyl=type
+jGcyp=isinstance
+jGcyU=list
+jGcyB=False
 import re
 import json
 import logging
@@ -19,21 +22,20 @@ from dulwich.client import get_transport_and_path_from_url
 from localstack import config
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import(load_file,to_str,to_bytes,mkdir,save_file,cp_r,run,is_command_available,clone,retry,safe_requests,disk_usage)
-from localstack_ext.utils import auth
+from localstack_ext.bootstrap.licensing import get_auth_headers
 LOG=logging.getLogger(__name__)
 PERISTED_FOLDERS=['api_states','dynamodb','kinesis']
-class CloudPodManager(aEDPU):
+class CloudPodManager(jGcyT):
  BACKEND='_none_'
- CONFIG_FILE='.localstack.yml'
- def __init__(self,pod_name=aEDPV,config=aEDPV):
+ def __init__(self,pod_name=jGcyH,config=jGcyH):
   self.pod_name=pod_name
-  self.config=config
+  self._pod_config=config
  def push(self):
-  raise aEDPC('Not implemented')
+  raise jGcyA('Not implemented')
  def pull(self):
-  raise aEDPC('Not implemented')
+  raise jGcyA('Not implemented')
  def get_pod_size(self):
-  raise aEDPC('Not implemented')
+  raise jGcyA('Not implemented')
  def restart_container(self):
   LOG.info('Restarting LocalStack instance with updated persistence state - this may take some time ...')
   data={'action':'restart'}
@@ -47,29 +49,20 @@ class CloudPodManager(aEDPU):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content['services'].items()]
-   assert aEDPT(statuses)==aEDPT(['running'])
+   assert jGcyI(statuses)==jGcyI(['running'])
   retry(check_status,sleep=3,retries=10)
- @aEDPh
+ @jGcyx
  def pod_config(self):
-  return self.config.get('pods',{}).get(self.pod_name)
- @aEDPm
- def get(cls,pod_name,config=aEDPV):
-  config=config or CloudPodManager.load_config()
-  pod_config=_pod_config(pod_name,config=config)
+  return self._pod_config or PodConfigManager.pod_config(self.pod_name)
+ @jGcyq
+ def get(cls,pod_name):
+  pod_config=PodConfigManager.pod_config(pod_name)
   backend=pod_config.get('backend')
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
-    return clazz(pod_name=pod_name,config=config)
-  raise aEDPC('Unable to find Cloud Pod manager implementation type "%s"'%backend)
- @aEDPm
- def load_config(cls,safe=aEDPy):
-  try:
-   return yaml.load(to_str(load_file(cls.CONFIG_FILE)))
-  except aEDPC:
-   if safe:
-    return{}
-   raise aEDPC('Unable to find and parse config file "%s"'%cls.CONFIG_FILE)
- @aEDPm
+    return clazz(pod_name=pod_name,config=pod_config)
+  raise jGcyA('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+ @jGcyq
  def data_dir(cls):
   if not config.DATA_DIR:
    try:
@@ -81,10 +74,10 @@ class CloudPodManager(aEDPU):
     data_dir_host=[m for m in mounts if m['Destination']==data_dir_env][0]['Source']
     data_dir_host=re.sub(r'^(/host_mnt)?',r'',data_dir_host)
     config.DATA_DIR=data_dir_host
-   except aEDPC:
+   except jGcyA:
     LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
   if not config.DATA_DIR:
-   raise aEDPC('Working with local cloud pods requires $DATA_DIR configuration')
+   raise jGcyA('Working with local cloud pods requires $DATA_DIR configuration')
   return config.DATA_DIR
 class CloudPodManagerGit(CloudPodManager):
  BACKEND='git'
@@ -95,9 +88,9 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get('url')
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except aEDPC as e:
+  except jGcyA as e:
    LOG.info('Unable to pull repo: %s'%e)
-  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==aEDPT([b'HEAD'])
+  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==jGcyI([b'HEAD'])
   if is_empty_repo:
    LOG.debug('Initializing empty repository %s'%self.clone_dir)
    init_file=os.path.join(self.clone_dir,'.init')
@@ -105,7 +98,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message='Initial commit')
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=aEDPA)
+   porcelain.branch_create(repo,branch,force=jGcyR)
   self.switch_branch(branch)
   for folder in PERISTED_FOLDERS:
    LOG.info('Copying persistence folder %s to local git repo %s'%(folder,self.clone_dir))
@@ -126,7 +119,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get('branch')
   remote_ref=b'refs/heads/%s'%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise aEDPC('Unable to find branch "%s" in remote git repo'%branch)
+   raise jGcyA('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get('url')
   self.switch_branch(branch)
   branch_ref=b'refs/heads/%s'%to_bytes(branch)
@@ -138,13 +131,13 @@ class CloudPodManagerGit(CloudPodManager):
   for folder in PERISTED_FOLDERS:
    src_folder=os.path.join(self.clone_dir,folder)
    tgt_folder=os.path.join(self.data_dir(),folder)
-   cp_r(src_folder,tgt_folder)
+   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=jGcyR)
   self.restart_container()
  def client(self):
   client,path=get_transport_and_path_from_url(self.pod_config.get('url'))
   return client,path
  def local_repo(self):
-  self.clone_dir=aEDPG(self,'clone_dir',aEDPV)
+  self.clone_dir=jGcyY(self,'clone_dir',jGcyH)
   if not self.clone_dir:
    pod_dir_name=re.sub(r'(\s|/)+','',self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,'pods',pod_dir_name,'repo')
@@ -164,42 +157,83 @@ class CloudPodManagerGit(CloudPodManager):
  def get_pod_size(self):
   self.local_repo()
   return disk_usage(self.clone_dir)
+class PodConfigManagerMeta(jGcyl):
+ def __getattr__(cls,attr):
+  def _call(*args,**kwargs):
+   result=jGcyH
+   for manager in cls.CHAIN:
+    try:
+     tmp=jGcyY(manager,attr)(*args,**kwargs)
+     if tmp:
+      if not result:
+       result=tmp
+      elif jGcyp(tmp,jGcyU)and jGcyp(result,jGcyU):
+       result.extend(tmp)
+    except jGcyA:
+     pass
+   if result is not jGcyH:
+    return result
+   raise jGcyA('Unable to run operation "%s" for local or remote configuration'%attr)
+  return _call
+class PodConfigManager(jGcyT,metaclass=PodConfigManagerMeta):
+ CHAIN=[]
+ @jGcyq
+ def pod_config(cls,pod_name):
+  pods=PodConfigManager.list_pods()
+  pod_config=[pod for pod in pods if pod['pod_name']==pod_name]
+  if not pod_config:
+   raise jGcyA('Unable to find config for pod named "%s"'%pod_name)
+  return pod_config[0]
+class PodConfigManagerLocal(jGcyT):
+ CONFIG_FILE='.localstack.yml'
+ def list_pods(self):
+  local_pods=self._load_config(safe=jGcyR).get('pods',{})
+  local_pods=[{'pod_name':k,'state':'Local Only',**v}for k,v in local_pods.items()]
+  existing_names=jGcyI([pod['pod_name']for pod in local_pods])
+  result=[pod for pod in local_pods if pod['pod_name']not in existing_names]
+  return result
+ def store_pod_metadata(self,pod_name,metadata):
+  pass
+ def _load_config(self,safe=jGcyB):
+  try:
+   return yaml.load(to_str(load_file(self.CONFIG_FILE)))
+  except jGcyA:
+   if safe:
+    return{}
+   raise jGcyA('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
+class PodConfigManagerRemote(jGcyT):
+ def list_pods(self):
+  result=[]
+  auth_headers=get_auth_headers()
+  response=safe_requests.get('%s/cloudpods'%API_ENDPOINT,headers=auth_headers)
+  content=response.content
+  if response.status_code>=400:
+   raise jGcyA('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
+  remote_pods=json.loads(to_str(content)).get('cloudpods',[])
+  remote_pods=[{'state':'Shared',**pod}for pod in remote_pods]
+  result.extend(remote_pods)
+  return result
+ def store_pod_metadata(self,pod_name,metadata):
+  auth_headers=get_auth_headers()
+  metadata['pod_name']=pod_name
+  response=safe_requests.post('%s/cloudpods'%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
+  content=response.content
+  if response.status_code>=400:
+   raise jGcyA('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
+  return json.loads(to_str(content))
+PodConfigManager.CHAIN.append(PodConfigManagerLocal())
+PodConfigManager.CHAIN.append(PodConfigManagerRemote())
 def push_state(pod_name,args):
  backend=CloudPodManager.get(pod_name=pod_name)
  pod_config=clone(backend.pod_config)
  pod_config['size']=backend.get_pod_size()
- store_pod_metadata(pod_name,pod_config)
+ PodConfigManager.store_pod_metadata(pod_name,pod_config)
  backend.push()
 def pull_state(pod_name,args):
+ if not pod_name:
+  raise jGcyA('Need to specify a pod name')
  backend=CloudPodManager.get(pod_name=pod_name)
  backend.pull()
-def store_pod_metadata(pod_name,metadata):
- auth_headers=auth.get_auth_headers()
- metadata['pod_name']=pod_name
- response=safe_requests.post('%s/cloudpods'%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
- content=response.content
- if response.status_code>=400:
-  raise aEDPC('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
- return json.loads(to_str(content))
 def list_pods(args):
- result=[]
- auth_headers=auth.get_auth_headers()
- response=safe_requests.get('%s/cloudpods'%API_ENDPOINT,headers=auth_headers)
- content=response.content
- if response.status_code>=400:
-  raise aEDPC('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
- remote_pods=json.loads(to_str(content)).get('cloudpods',[])
- remote_pods=[{'state':'Shared',**pod}for pod in remote_pods]
- result.extend(remote_pods)
- local_pods=CloudPodManager.load_config(safe=aEDPA).get('pods',{})
- local_pods=[{'pod_name':k,'state':'Local Only',**v}for k,v in local_pods.items()]
- existing_names=aEDPT([pod['pod_name']for pod in result])
- result.extend([pod for pod in local_pods if pod['pod_name']not in existing_names])
- return result
-def _pod_config(pod_name,config=aEDPV):
- config=config or CloudPodManager.load_config()
- pod_config=config.get('pods',{}).get(pod_name)
- if not pod_config:
-  raise aEDPC('Unable to find config for pod named "%s"'%pod_name)
- return pod_config
+ return PodConfigManager.list_pods()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
