@@ -24,6 +24,7 @@ API_PATH_UNSUBSCRIBE = '%s/unsubscribe' % API_PATH_USER
 API_PATH_KEY_ACTIVATE = '%s/activate' % API_PATH
 API_PATH_CARDS = '%s/cards' % API_PATH_USER
 API_PATH_PLANS = '%s/plans' % API_PATH
+API_PATH_FEEDBACKS = '%s/feedbacks' % API_PATH
 API_PATH_SUBSCRIPTIONS = '%s/subscriptions' % API_PATH_PLANS
 API_PATH_INVOICES = '%s/invoices' % API_PATH_PLANS
 API_PATH_CLOUDPODS = '%s/cloudpods' % API_PATH
@@ -44,8 +45,9 @@ DB_NAME = 'localstack'
 DB_USER = os.environ.get('DB_USER') or 'localstack'
 DB_PASS = os.environ.get('DB_PASS')
 
-# localhost IP address
+# localhost IP address and hostname
 LOCALHOST_IP = '127.0.0.1'
+LOCAL_HOSTNAME = 'localhost.localstack.cloud'
 
 # bind address of local DNS server
 DNS_ADDRESS = os.environ.get('DNS_ADDRESS') or '0.0.0.0'
@@ -57,7 +59,7 @@ DNS_ADDRESS = os.environ.get('DNS_ADDRESS') or '0.0.0.0'
 DNS_RESOLVE_IP = os.environ.get('DNS_RESOLVE_IP') or LOCALHOST_IP
 
 # fallback DNS server to send upstream requests to
-DNS_SERVER = os.environ.get('DNS_SERVER', '8.8.8.8')
+DNS_SERVER = os.environ.get('DNS_SERVER')
 
 # SMTP settings (required, e.g., for Cognito)
 SMTP_HOST = os.environ.get('SMTP_HOST', '')
@@ -119,6 +121,7 @@ DOCKER_HOST_NAME = 'host.docker.internal'
 PORT_HIVE_METASTORE = 9083
 PORT_HIVE_SERVER = 10000
 PORT_SPARK_MASTER = 7077
+PORT_SPARK_UI = 4040
 
 if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
     # special case when we're running tests outside of Docker
