@@ -1,11 +1,11 @@
 import os
-rNKBS=Exception
-rNKBn=any
-rNKBd=str
-rNKBX=None
-rNKBo=False
-rNKBi=bool
-rNKBP=True
+IasXP=Exception
+IasXD=any
+IasXJ=str
+IasXL=None
+IasXm=False
+IasXt=bool
+IasXC=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -14,7 +14,7 @@ from localstack.utils.bootstrap import is_api_enabled,API_DEPENDENCIES
 from localstack_ext import config as config_ext
 from localstack_ext.bootstrap import licensing,cli,install,local_daemon
 LOG=logging.getLogger(__name__)
-EXTERNAL_PORT_APIS=('apigateway','athena','cloudfront','codecommit','ecs','ecr','elasticache','mediastore','rds','transfer','kafka','neptune','azure')
+EXTERNAL_PORT_APIS=('apigateway','apigatewayv2','athena','cloudfront','codecommit','ecs','ecr','elasticache','mediastore','rds','transfer','kafka','neptune','azure')
 def register_localstack_plugins():
  _setup_logging()
  is_infra_process=os.environ.get(LOCALSTACK_INFRA_PROCESS)in TRUE_STRINGS
@@ -29,42 +29,45 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except rNKBS:
+  except IasXP:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except rNKBS as e:
+  except IasXP as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured:
-   port=localstack_config.EDGE_PORT
-   if not os.environ.get('EDGE_PORT'):
+   if os.environ.get('EDGE_PORT')and not localstack_config.EDGE_PORT_HTTP:
+    LOG.warning(('!! Configuring EDGE_PORT={p} without setting EDGE_PORT_HTTP may lead '+'to issues; better leave the defaults, or set EDGE_PORT=443 and EDGE_PORT_HTTP={p}').format(p=localstack_config.EDGE_PORT))
+   else:
+    port=localstack_config.EDGE_PORT
     localstack_config.EDGE_PORT=443
-   localstack_config.EDGE_PORT_HTTP=port
+    localstack_config.EDGE_PORT_HTTP=port
  API_DEPENDENCIES['apigateway']=['apigatewayv2']
- API_DEPENDENCIES['emr']=['athena','s3']
  API_DEPENDENCIES['athena']=['emr']
+ API_DEPENDENCIES['docdb']=['rds']
+ API_DEPENDENCIES['ecs']=['ecr']
+ API_DEPENDENCIES['elasticache']=['ec2']
+ API_DEPENDENCIES['elb']=['elbv2']
+ API_DEPENDENCIES['emr']=['athena','s3']
+ API_DEPENDENCIES['glacier']=['s3']
+ API_DEPENDENCIES['glue']=['rds']
+ API_DEPENDENCIES['iot']=['iotanalytics','iot-data','iotwireless']
+ API_DEPENDENCIES['kinesisanalytics']=['kinesis','dynamodb']
+ API_DEPENDENCIES['neptune']=['rds']
  API_DEPENDENCIES['rds']=['rds-data']
  API_DEPENDENCIES['redshift']=['redshift-data']
- API_DEPENDENCIES['glacier']=['s3']
- API_DEPENDENCIES['transfer']=['s3']
- API_DEPENDENCIES['elasticache']=['ec2']
- API_DEPENDENCIES['ecs']=['ecr']
- API_DEPENDENCIES['glue']=['rds']
- API_DEPENDENCIES['kinesisanalytics']=['kinesis','dynamodb']
- API_DEPENDENCIES['iot']=['iotanalytics','iot-data']
  API_DEPENDENCIES['timestream']=['timestream-write','timestream-query']
- API_DEPENDENCIES['elb']=['elbv2']
- API_DEPENDENCIES['neptune']=['rds']
+ API_DEPENDENCIES['transfer']=['s3']
  docker_flags=[]
  if config_ext.use_custom_dns():
   if not common.is_port_open(dns_server.DNS_PORT,protocols='tcp'):
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if rNKBn([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if IasXD([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
@@ -93,12 +96,13 @@ def load_plugin_files():
   from localstack_ext.services.cloudtrail import cloudtrail_starter
   from localstack_ext.services.codecommit import codecommit_starter,codecommit_listener
   from localstack_ext.services.cognito import cognito_starter,cognito_listener
+  from localstack_ext.services.docdb import docdb_api
   from localstack_ext.services.dynamodb import dynamodb_extended
   from localstack_ext.services.ecr import ecr_starter,ecr_listener
   from localstack_ext.services.ecs import ecs_starter,ecs_listener
   from localstack_ext.services.eks import eks_starter
   from localstack_ext.services.elasticache import elasticache_starter
-  from localstack_ext.services.elb import elb_starter
+  from localstack_ext.services.elb import elb_starter,elb_listener
   from localstack_ext.services.emr import emr_starter,emr_listener
   from localstack_ext.services.events import events_extended
   from localstack_ext.services.glacier import glacier_starter,glacier_listener
@@ -114,9 +118,12 @@ def load_plugin_files():
   from localstack_ext.services.qldb import qldb_starter
   from localstack_ext.services.rds import rds_starter,rds_listener
   from localstack_ext.services.redshift import redshift_starter,redshift_listener
+  from localstack_ext.services.route53 import route53_extended
   from localstack_ext.services.s3 import s3_extended
   from localstack_ext.services.sagemaker import sagemaker_starter
   from localstack_ext.services.secretsmanager import secretsmanager_extended
+  from localstack_ext.services.serverlessrepo import serverlessrepo_starter
+  from localstack_ext.services.servicediscovery import servicediscovery_starter
   from localstack_ext.services.ses import ses_extended
   from localstack_ext.services.sns import sns_extended
   from localstack_ext.services.sqs import sqs_extended
@@ -139,9 +146,10 @@ def load_plugin_files():
   register_plugin(Plugin('codecommit',start=codecommit_starter.start_codecommit,listener=codecommit_listener.UPDATE_CODECOMMIT))
   register_plugin(Plugin('cognito-identity',start=cognito_starter.start_cognito_identity,listener=cognito_listener.UPDATE_COGNITO_IDENTITY))
   register_plugin(Plugin('cognito-idp',start=cognito_starter.start_cognito_idp,listener=cognito_listener.UPDATE_COGNITO))
+  register_plugin(Plugin('docdb',start=docdb_api.start_docdb))
   register_plugin(Plugin('elasticache',start=elasticache_starter.start_elasticache))
-  register_plugin(Plugin('elb',start=elb_starter.start_elb))
-  register_plugin(Plugin('elbv2',start=elb_starter.start_elbv2))
+  register_plugin(Plugin('elb',start=elb_starter.start_elb,listener=elb_listener.UPDATE_ELB))
+  register_plugin(Plugin('elbv2',start=elb_starter.start_elbv2,listener=elb_listener.UPDATE_ELB))
   register_plugin(Plugin('ecr',start=ecr_starter.start_ecr,listener=ecr_listener.UPDATE_ECR))
   register_plugin(Plugin('ecs',start=ecs_starter.start_ecs,listener=ecs_listener.UPDATE_ECS))
   register_plugin(Plugin('eks',start=eks_starter.start_eks))
@@ -159,6 +167,8 @@ def load_plugin_files():
   register_plugin(Plugin('rds',start=rds_starter.start_rds,listener=rds_listener.UPDATE_RDS))
   register_plugin(Plugin('redshift',start=redshift_starter.start_redshift,listener=redshift_listener.UPDATE_REDSHIFT,priority=10))
   register_plugin(Plugin('sagemaker',start=sagemaker_starter.start_sagemaker))
+  register_plugin(Plugin('serverlessrepo',start=serverlessrepo_starter.start_serverlessrepo))
+  register_plugin(Plugin('servicediscovery',start=servicediscovery_starter.start_servicediscovery))
   register_plugin(Plugin('timestream',start=timestream_starter.start_timestream))
   register_plugin(Plugin('transfer',start=transfer_starter.start_transfer))
   register_plugin(Plugin('xray',start=xray_starter.start_xray,listener=xray_listener.UPDATE_XRAY))
@@ -176,28 +186,29 @@ def load_plugin_files():
   secretsmanager_extended.patch_secretsmanager()
   sts_extended.patch_sts()
   ses_extended.patch_ses()
+  route53_extended.patch_route53()
   dashboard_extended.patch_dashboard()
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except rNKBS as e:
-  if 'No module named' not in rNKBd(e):
-   print(e)
+ except IasXP as e:
+  if 'No module named' not in IasXJ(e):
+   print('ERROR: %s'%e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except rNKBS:
-  start_metadata_service=rNKBX
+ except IasXP:
+  start_metadata_service=IasXL
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except rNKBS:
+   except IasXP:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=rNKBo
+   config_ext.ENFORCE_IAM=IasXm
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -220,9 +231,9 @@ def _setup_logging():
  logging.getLogger('root').setLevel(logging.WARNING)
  logging.getLogger('').setLevel(logging.WARNING)
 def api_key_configured():
- return rNKBi(os.environ.get('LOCALSTACK_API_KEY'))
+ return IasXt(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return rNKBP
+ return IasXC
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
